@@ -15,7 +15,7 @@ class ServiceDescriptor(object):
         """
         Metadata service descriptor.
 
-        :param attributes: conforming to the Metadata accepted by Ocean Protocol, dict
+        :param attributes: conforming to the Metadata accepted by Nevermined, dict
         :param service_endpoint: identifier of the service inside the asset DDO, str
         :return: Service descriptor.
         """
@@ -62,6 +62,48 @@ class ServiceDescriptor(object):
             {'attributes': attributes, 'serviceEndpoint': service_endpoint}
         )
 
+    @staticmethod
+    def did_sales_service_descriptor(attributes, service_endpoint):
+        """
+        DID Sales service descriptor.
+
+        :param attributes: attributes of the did sales service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service descriptor.
+        """
+        return (
+            ServiceTypes.DID_SALES,
+            {'attributes': attributes, 'serviceEndpoint': service_endpoint}
+        )
+
+    @staticmethod
+    def nft_sales_service_descriptor(attributes, service_endpoint):
+        """
+        NFT Sales service descriptor.
+
+        :param attributes: attributes of the nft sales service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service descriptor.
+        """
+        return (
+            ServiceTypes.NFT_SALES,
+            {'attributes': attributes, 'serviceEndpoint': service_endpoint}
+        )
+
+    @staticmethod
+    def nft_access_service_descriptor(attributes, service_endpoint):
+        """
+        NFT Access service descriptor.
+
+        :param attributes: attributes of the nft access service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service descriptor.
+        """
+        return (
+            ServiceTypes.NFT_ACCESS,
+            {'attributes': attributes, 'serviceEndpoint': service_endpoint}
+        )
+
 
 class ServiceFactory(object):
     """Factory class to create Services."""
@@ -102,13 +144,11 @@ class ServiceFactory(object):
                 kwargs['attributes'],
                 kwargs['serviceEndpoint']
             )
-
         elif service_type == ServiceTypes.AUTHORIZATION:
             return ServiceFactory.build_authorization_service(
                 kwargs['attributes'],
                 kwargs['serviceEndpoint']
             )
-
         elif service_type == ServiceTypes.ASSET_ACCESS:
             return ServiceFactory.build_access_service(
                 kwargs['attributes'],
@@ -119,6 +159,22 @@ class ServiceFactory(object):
                 kwargs['attributes'],
                 kwargs['serviceEndpoint']
             )
+        elif service_type == ServiceTypes.DID_SALES:
+            return ServiceFactory.build_did_sales_service(
+                kwargs['attributes'],
+                kwargs['serviceEndpoint']
+            )
+        elif service_type == ServiceTypes.NFT_SALES:
+            return ServiceFactory.build_nft_sales_service(
+                kwargs['attributes'],
+                kwargs['serviceEndpoint']
+            )
+        elif service_type == ServiceTypes.NFT_ACCESS:
+            return ServiceFactory.build_nft_access_service(
+                kwargs['attributes'],
+                kwargs['serviceEndpoint']
+            )
+
         raise ValueError(f'Unknown service type {service_type}')
 
     @staticmethod
@@ -126,7 +182,7 @@ class ServiceFactory(object):
         """
         Build a metadata service.
 
-        :param metadata: conforming to the Metadata accepted by Ocean Protocol, dict
+        :param metadata: conforming to the Metadata accepted by Nevermined, dict
         :param service_endpoint: identifier of the service inside the asset DDO, str
         :return: Service
         """
@@ -152,7 +208,7 @@ class ServiceFactory(object):
     @staticmethod
     def build_access_service(attributes, service_endpoint):
         """
-        Build an authorization service.
+        Build an access service.
 
         :param attributes: attributes of access service, dict
         :param service_endpoint: identifier of the service inside the asset DDO, str
@@ -165,7 +221,7 @@ class ServiceFactory(object):
     @staticmethod
     def build_compute_service(attributes, service_endpoint):
         """
-        Build an authorization service.
+        Build a compute service.
 
         :param attributes: attributes of compute service, dict
         :param service_endpoint: identifier of the service inside the asset DDO, str
@@ -175,9 +231,48 @@ class ServiceFactory(object):
                        values={'attributes': attributes},
                        index=ServiceTypesIndices.DEFAULT_COMPUTING_INDEX)
 
+    @staticmethod
+    def build_did_sales_service(attributes, service_endpoint):
+        """
+        Build a did sales service.
+
+        :param attributes: attributes of did sales service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service
+        """
+        return Service(service_endpoint, ServiceTypes.DID_SALES,
+                       values={'attributes': attributes},
+                       index=ServiceTypesIndices.DEFAULT_DID_SALES_INDEX)
+
+    @staticmethod
+    def build_nft_sales_service(attributes, service_endpoint):
+        """
+        Build a nft sales service.
+
+        :param attributes: attributes of nft sales service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service
+        """
+        return Service(service_endpoint, ServiceTypes.NFT_SALES,
+                       values={'attributes': attributes},
+                       index=ServiceTypesIndices.DEFAULT_NFT_SALES_INDEX)
+
+    @staticmethod
+    def build_nft_access_service(attributes, service_endpoint):
+        """
+        Build a nft sales service.
+
+        :param attributes: attributes of nft sales service, dict
+        :param service_endpoint: identifier of the service inside the asset DDO, str
+        :return: Service
+        """
+        return Service(service_endpoint, ServiceTypes.NFT_ACCESS,
+                       values={'attributes': attributes},
+                       index=ServiceTypesIndices.DEFAULT_NFT_ACCESS_INDEX)
+
     @staticmethod
     def complete_access_service(did, service_endpoint, attributes, template_id,
-                                reward_contract_address):
+                                reward_contract_address=None, service_type=ServiceTypes.ASSET_ACCESS):
         """
         Build the access service.
 
@@ -190,18 +285,21 @@ class ServiceFactory(object):
         """
         param_map = {
             '_documentId': did_to_id(did),
-            '_amount': attributes['main']['price'],
-            '_rewardAddress': reward_contract_address
+            '_amount': attributes['main']['price']
         }
 
+        if reward_contract_address is not None:
+            param_map ['_rewardAddress'] = reward_contract_address
+
         try:
             param_map['_amounts'] = attributes['main']['_amounts']
             param_map['_receivers'] = attributes['main']['_receivers']
+            param_map['_numberNfts'] = attributes['main']['_numberNfts']
         except KeyError:
             pass
         
-        sla_template_dict = get_sla_template()
-        sla_template = ServiceAgreementTemplate(template_id, ServiceTypes.ASSET_ACCESS,
+        sla_template_dict = get_sla_template(service_type)
+        sla_template = ServiceAgreementTemplate(template_id, service_type,
                                                 attributes['main']['creator'], sla_template_dict)
         sla_template.template_id = template_id
         conditions = sla_template.conditions[:]
@@ -218,7 +316,7 @@ class ServiceFactory(object):
             attributes,
             sla_template,
             service_endpoint,
-            ServiceTypes.ASSET_ACCESS
+            service_type
         )
         return sa
 
@@ -267,3 +365,4 @@ class ServiceFactory(object):
             ServiceTypes.CLOUD_COMPUTE
         )
         return sa
+
