@@ -38,6 +38,7 @@ def test_nft_sales_flow(setup_nft_sales_agreements_environment):
     amounts = service_agreement.get_amounts_int()
     receivers = service_agreement.get_receivers()
     number_nfts = service_agreement.get_number_nfts()
+    token_address = keeper.token.address
 
     receiver_0_starting_balance = keeper.token.get_token_balance(
         keeper.agreement_manager.to_checksum_address(receivers[0]))
@@ -90,6 +91,7 @@ def test_nft_sales_flow(setup_nft_sales_agreements_environment):
         agreement_id,
         asset_id,
         keeper.escrow_payment_condition.address,
+        token_address,
         amounts,
         receivers,
         consumer_acc)
@@ -135,7 +137,7 @@ def test_nft_sales_flow(setup_nft_sales_agreements_environment):
     # Fulfill escrow_payment_condition
     tx_hash = keeper.escrow_payment_condition.fulfill(
         agreement_id, asset_id, amounts, receivers,
-        keeper.escrow_payment_condition.address, lock_cond_id,
+        keeper.escrow_payment_condition.address, token_address, lock_cond_id,
         access_cond_id, publisher_acc
     )
 
